# amapy-plugin-gcr

The GCR plugin for the ama project. It provides functionalities to
manage and integrate Google Cloud Registry (GCR) within the asset management system.

## Installation

The source code is currently hosted on GitHub at:
https://github.com/Roche-CSI/ama

Binary installers for the latest released version are available at the
[Python Package Index (PyPI)](https://pypi.org/project/amapy-plugin-gcr/)

You can install using [pip](https://pip.pypa.io/en/stable/):

```sh
pip install amapy-plugin-gcr
```

## Supported Python Versions

Python == 3.10

## License

MIT License - see [LICENSE](https://github.com/Roche-CSI/ama/blob/main/LICENSE) for details.
